@@ -2,8 +2,10 @@
 
 #include <config.h>
 #include <gnome.h>
-#include <applet-widget.h>
-#define CHARPICK_VERSION "0.04"
+#include <panel-applet.h>
+#include <panel-applet-gconf.h>
+
+#define CHARPICK_VERSION "0.05"
 #define NO_LAST_INDEX -1
 #define DEFAULT_ROWS 2
 #define DEFAULT_COLS 4
@@ -43,9 +45,6 @@ struct _charpick_data {
   charpick_persistant_properties * properties;
 };
 
-/* typedef struct _prop_sb_cb_data prop_sb_cb_data; */
-
-
 
 typedef struct _charpick_button_cb_data charpick_button_cb_data;
 /* This is the data type for the button callback function. */
@@ -55,16 +54,13 @@ struct _charpick_button_cb_data {
   charpick_data * p_curr_data;
 };
 
-/*static const gchar *def_list = "";*/
-
-extern charpick_data curr_data;
 
 void start_callback_update();
 
 void build_table(charpick_data *curr_data);
-void property_load(char *path, gpointer data);
+void property_load(charpick_data *curr_data);
 void property_save(char *path, charpick_persistant_properties *properties);
-void property_show(AppletWidget *applet, gpointer data);
+void property_show(BonoboUIComponent *uic, gpointer data, const gchar *verbname);
 
 
 
