@@ -29,7 +29,8 @@
 #include <config.h>
 #include <string.h>
 #include <gnome.h>
-#include <applet-widget.h>
+
+#include <panel-applet.h>
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <libart_lgpl/art_alphagamma.h>
@@ -48,7 +49,6 @@ typedef struct _GkbWindow          GkbWindow;
 typedef struct _GkbKeymapWg        GkbKeymapWg;
 typedef struct _GkbPropertyBoxInfo GkbPropertyBoxInfo;
 
-
 typedef enum {
   GKB_LABEL,
   GKB_FLAG,
@@ -80,6 +80,8 @@ struct _GkbPropertyBoxInfo
   /* Selected keymap to add */
   GkbKeymap *keymap_for_add;
 
+  GtkTreeStore *model;
+
   /* Other properties */
   gint is_small; 
   GkbMode mode;
@@ -110,7 +112,7 @@ struct _GKB
   GList *maps;
   
   /* Properties */
-  PanelOrientType orient;
+  PanelAppletOrient orient;
   GkbMode mode;
   gint is_small;
   gint w;
@@ -165,10 +167,13 @@ struct _GkbKeymapWg
 
 /* gkb.c */
 void gkb_update (GKB *gkb, gboolean set_command);
-
+void alert (const gchar * str);
+void applet_save_session ();
 
 /* prop.c */
-void properties_dialog (AppletWidget * applet);
+void properties_dialog (BonoboUIComponent *uic,
+                        GKB	 *gkb,
+                        const gchar	 *verbname);
 void gkb_sized_render (GKB * gkb);
 
 /* presets.c */
@@ -209,8 +214,15 @@ char * convert_keysym_state_to_string(guint keysym,
 					guint state);
 void grab_button_pressed (GtkButton *button, gpointer data);
 
-
+void gkb_xgrab(gint keycode, gint modifiers);
+void gkb_xungrab(gint keycode, gint modifiers);
 
 /* Globals */
 gchar * prefixdir;
 GKB * gkb;
+
+G_BEGIN_DECLS
+
+gboolean fill_gkb_applet(PanelApplet *applet);
+
+G_END_DECLS
