@@ -1,5 +1,5 @@
 /* GNOME modemlights applet
- * (C) 1999 John Ellis
+ * (C) 2000 John Ellis
  *
  * Authors: John Ellis
  *          Martin Baulig
@@ -8,6 +8,7 @@
 
 #include <config.h>
 
+#include <panel-applet.h>
 #include <stdio.h>
 #include <string.h>
 #include <sys/stat.h>
@@ -29,7 +30,42 @@
 #include <net/ppp_defs.h>
 
 #include <gnome.h>
-#include <applet-widget.h>
+
+typedef enum {
+	COLOR_RX = 0,
+	COLOR_RX_BG,
+	COLOR_TX,
+	COLOR_TX_BG,
+	COLOR_STATUS_BG,
+	COLOR_STATUS_OK,
+	COLOR_STATUS_WAIT,
+	COLOR_TEXT_BG,
+	COLOR_TEXT_FG,
+	COLOR_TEXT_MID
+} ColorType;
+#define COLOR_COUNT 10
+
+typedef struct _MLData MLData;
+
+struct _MLData
+{
+	GtkWidget *applet;
+	
+	gint UPDATE_DISPLAY;
+	gchar *lock_file;
+	gint verify_lock_file;
+	gchar *device_name;
+	gchar *command_connect;
+	gchar *command_disconnect;
+	gint ask_for_confirmation;
+	gint use_ISDN;
+	gint show_extra_info;
+	gint status_wait_blink;
+	
+};
+
+extern GdkColor display_color[];
+extern gchar *display_color_text[];
 
 extern gint UPDATE_DELAY;
 extern gchar *lock_file;
@@ -40,14 +76,15 @@ extern int ask_for_confirmation;
 extern gchar *device_name;
 extern gint use_ISDN;
 extern gint show_extra_info;
-
-extern GtkWidget *applet;
+extern gint status_wait_blink;
 
 void start_callback_update(void);
 void reset_orientation(void);
+void reset_colors(void);
+
+void property_load(PanelApplet *applet);
+void property_show(BonoboUIComponent *uic, gpointer data, const gchar *verbname);
+
 
-void property_load(char *path);
-void property_save(char *path);
-void property_show(AppletWidget *applet, gpointer data);
 
 
